@@ -45,12 +45,14 @@
 #include "pascalprojectoptionsdlg.h"
 #include "pascalglobaloptionsdlg.h"
 
+#include <kdevplugininfo.h>
+
 typedef KDevGenericFactory<PascalProjectPart> PascalProjectFactory;
-static const KAboutData data("kdevpascalproject", I18N_NOOP("Build Tool"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevpascalproject, PascalProjectFactory( &data ) )
+static const KDevPluginInfo data("kdevpascalproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevpascalproject, PascalProjectFactory( data ) )
 
 PascalProjectPart::PascalProjectPart(QObject *parent, const char *name, const QStringList& )
-    :KDevProject("PascalProject", "pascalproject", parent, name ? name : "PascalProjectPart" )
+    :KDevBuildTool(&data, parent, name ? name : "PascalProjectPart" )
 {
     setInstance(PascalProjectFactory::instance());
     setXMLFile("kdevpascalproject.rc");
@@ -194,23 +196,7 @@ DomUtil::PairList PascalProjectPart::runEnvironmentVars() const
   */
 QString PascalProjectPart::runDirectory() const
 {
-    QDomDocument &dom = *projectDom();
-
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevpascalproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevpascalproject/run/mainprogram");
-
-    if ( directoryRadioString == "build" )
-        return buildDirectory();
-
-    if ( directoryRadioString == "custom" )
-        return DomUtil::readEntry(dom, "/kdevpascalproject/run/customdirectory");
-
-    int pos = DomMainProgram.findRev('/');
-    if (pos != -1)
-        return buildDirectory() + "/" + DomMainProgram.left(pos);
-
-    return buildDirectory() + "/" + DomMainProgram;
-
+    return defaultRunDirectory("kdevpascalproject");
 }
 
 
@@ -343,7 +329,8 @@ void PascalProjectPart::removeFiles(const QStringList& /*fileList*/)
 
 void PascalProjectPart::slotBuild()
 {
-    partController()->saveAllFiles();
+    if (partController()->saveAllFiles()==false)
+       return; //user cancelled
 
     QString cmdline = m_compilerExec + " " + m_compilerOpts + " ";
 
@@ -418,7 +405,7 @@ void PascalProjectPart::projectConfigWidget( KDialogBase * dlg )
     connect( dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
     connect( dlg, SIGNAL(okClicked()), this, SLOT(loadProjectConfig()) );
 
-    vbox = dlg->addVBoxPage(i18n("Run Options"));
+    vbox = dlg->addVBoxPage(i18n("Run Options"), i18n("Run Options"), BarIcon( "make", KIcon::SizeMedium ));
     RunOptionsWidget *w3 = new RunOptionsWidget(*projectDom(), "/kdevpascalproject", buildDirectory(), vbox);
     w3->mainprogram_label->setText(i18n("Main program (relative to project directory):"));
     connect( dlg, SIGNAL(okClicked()), w3, SLOT(accept()) );
