@@ -60,6 +60,7 @@ private slots:
     void guiClientAdded(KXMLGUIClient*);
     void contextMenu(QPopupMenu *popup, const Context *context);
     void toggleBreakpoint();
+    void contextEvaluate();
     void contextWatch();
 //    void projectOpened();
     void projectClosed();
@@ -67,12 +68,14 @@ private slots:
     void slotActivePartChanged(KParts::Part*);
 
     void slotRun();
+    void slotRestart();
     void slotExamineCore();
     void slotAttachProcess();
     void slotStopDebugger();
     void slotStop(KDevPlugin* which = 0);
     void slotPause();
     void slotRunToCursor();
+    void slotJumpToCursor();
     void slotStepOver();
     void slotStepOverInstruction();
     void slotStepIntoInstruction();
@@ -88,8 +91,7 @@ private slots:
     void slotDCOPApplicationRegistered(const QCString &appId);
     void slotCloseDrKonqi();
 
-    //! There was an error running the debugger
-    void errRunningDebugger( int errorCode );
+    void slotDebuggerAbnormalExit();
 
 private:
     KDevAppFrontend *appFrontend();
@@ -114,6 +116,11 @@ private:
     QCString m_drkonqi;
     
     KDevDebugger *m_debugger;
+    int previousDebuggerState_;
+    // Set to true after each debugger restart
+    // Currently used to auto-show variables view
+    // on the first pause.
+    bool justRestarted_;
 };
 
 }
