@@ -156,7 +156,11 @@ enum NodeType
     NodeType_WhileStatement,
     NodeType_DoStatement,
     NodeType_ForStatement,
+    NodeType_ForEachStatement, // qt4 [erbsland]
     NodeType_SwitchStatement,
+	NodeType_CatchStatement,
+    NodeType_CatchStatementList,
+	NodeType_TryBlockStatement,
     NodeType_DeclarationStatement,
     NodeType_TranslationUnit,
     NodeType_FunctionDefinition,
@@ -1304,6 +1308,37 @@ private:
     void operator = ( const ForStatementAST& source );
 };
 
+// qt4 [erbsland]
+class ForEachStatementAST: public StatementAST
+{
+public:
+    typedef AUTO_PTR<ForEachStatementAST> Node;
+    enum { Type = NodeType_ForEachStatement };
+
+    DECLARE_ALLOC( ForEachStatementAST )
+    
+public:
+    ForEachStatementAST();
+
+    StatementAST* initStatement() { return m_initStatement.get(); }
+    void setInitStatement( StatementAST::Node& statement );
+
+    StatementAST* statement() { return m_statement.get(); }
+    void setStatement( StatementAST::Node& statement );
+    
+    AST* expression() const { return m_expression.get(); }
+    void setExpression( AST::Node& expression );
+
+private:
+    StatementAST::Node m_initStatement;
+    StatementAST::Node m_statement;
+    AST::Node m_expression;
+
+private:
+    ForEachStatementAST( const ForEachStatementAST& source );
+    void operator = ( const ForEachStatementAST& source );
+};
+
 class SwitchStatementAST: public StatementAST
 {
 public:
@@ -1352,6 +1387,80 @@ private:
     void operator = ( const StatementListAST& source );
 };
 
+class CatchStatementAST: public StatementAST
+{
+public:
+    typedef AUTO_PTR<CatchStatementAST> Node;
+    enum { Type = NodeType_CatchStatement };
+
+    DECLARE_ALLOC( CatchStatementAST )
+    
+public:
+    CatchStatementAST();
+
+    ConditionAST* condition() const { return m_condition.get(); }
+    void setCondition( ConditionAST::Node& condition );
+
+    StatementAST* statement() { return m_statement.get(); }
+    void setStatement( StatementAST::Node& statement );
+
+private:
+    ConditionAST::Node m_condition;
+    StatementAST::Node m_statement;
+
+private:
+    CatchStatementAST( const CatchStatementAST& source );
+    void operator = ( const CatchStatementAST& source );
+};
+
+class CatchStatementListAST: public StatementAST
+{
+public:
+    typedef AUTO_PTR<CatchStatementListAST> Node;
+    enum { Type = NodeType_CatchStatementList };
+
+    DECLARE_ALLOC( CatchStatementListAST )
+    
+public:
+    CatchStatementListAST();
+
+    QPtrList<CatchStatementAST> statementList() { return m_statementList; }
+    void addStatement( CatchStatementAST::Node& statement );
+
+private:
+    QPtrList<CatchStatementAST> m_statementList;
+
+private:
+    CatchStatementListAST( const CatchStatementListAST& source );
+    void operator = ( const CatchStatementListAST& source );
+};
+
+class TryBlockStatementAST: public StatementAST
+{
+public:
+    typedef AUTO_PTR<TryBlockStatementAST> Node;
+    enum { Type = NodeType_TryBlockStatement };
+
+    DECLARE_ALLOC( TryBlockStatementAST )
+    
+public:
+    TryBlockStatementAST();
+
+    StatementAST* statement() { return m_statement.get(); }
+    void setStatement( StatementAST::Node& statement );
+
+    CatchStatementListAST* catchStatementList() { return m_catchStatementList.get(); }
+    void setCatchStatementList( CatchStatementListAST::Node& statementList );
+
+private:
+    StatementAST::Node m_statement;
+    CatchStatementListAST::Node m_catchStatementList;
+
+private:
+    TryBlockStatementAST( const TryBlockStatementAST& source );
+    void operator = ( const TryBlockStatementAST& source );
+};
+
 class DeclarationStatementAST: public StatementAST
 {
 public:
