@@ -4,7 +4,7 @@
    Copyright (C) 2002-2003 Roberto Raggi <roberto@kdevelop.org>
    Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>
    Copyright (C) 2002 F@lk Brettschneider <falkbr@kdevelop.org>
-   Copyright (C) 2003 Alexander Dymo <cloudtemple@mksat.net>
+   Copyright (C) 2003 Alexander Dymo <adymo@kdevelop.org>
    Copyright (C) 2003 Amilcar do Carmo Lucas <amilcar@ida.ing.tu-bs.de>
 
    This library is free software; you can redistribute it and/or
@@ -29,8 +29,8 @@
 #include "kdevdesignerintegration.h"
 #include "kdevlanguagesupport.h"
 
-KDevLanguageSupport::KDevLanguageSupport( const QString& pluginName, const QString& icon, QObject *parent, const char *name)
-    : KDevPlugin( pluginName, icon, parent, name ? name : "KDevLanguageSupport" )
+KDevLanguageSupport::KDevLanguageSupport(const KDevPluginInfo *info, QObject *parent, const char *name)
+    : KDevPlugin(info, parent, name ? name : "KDevLanguageSupport" )
 {
 }
 
@@ -125,7 +125,8 @@ void KDevLanguageSupport::removeFunction( DesignerType type, const QString & for
     designerIntegration->removeFunction(formName, function);
 }
 
-KDevDesignerIntegration * KDevLanguageSupport::designer( DesignerType type )
+KDevDesignerIntegration * KDevLanguageSupport::designer( DesignerType // type
+                                                         )
 {
     return 0;
 }
@@ -138,4 +139,18 @@ void KDevLanguageSupport::openFunction( DesignerType type, const QString & formN
     designerIntegration->openFunction(formName, functionName);
 }
 
+void KDevLanguageSupport::createAccessMethods( ClassDom // theClass
+                                               , VariableDom // theVariable
+                                               )
+{
+}
+
+void KDevLanguageSupport::openSource( DesignerType type, const QString & formName)
+{
+    KDevDesignerIntegration *designerIntegration = designer(type);
+    if (!designerIntegration)
+        return;
+    designerIntegration->openSource(formName);
+}
+
 #include "kdevlanguagesupport.moc"
