@@ -28,63 +28,74 @@ class KDevCore;
 class KDialogBase;
 
 /**
- * This class can be used to implement demand-loading of config pages.
- *
- * In order to avoid the potentially heavy and unneccessary creation
- * of a config page that might not be needed, this class can be used
- * to delay the config page creation until the user explicitly asks
- * for it.
+@file configwidgetproxy.h
+Configuration widget proxy class.
+*/
+
+/**
+This class can be used to implement demand-loading of config pages.
+In order to avoid the potentially heavy and unneccessary creation
+of a config page that might not be needed, this class can be used
+to delay the config page creation until the user explicitly asks
+for it.
  
- A typical case looks like this:
- <PRE>
- 
-#define BOOKMARKSETTINGSPAGE 1
+A typical case looks like this:
+@code
+#define GLOBALDOC_OPTIONS 1
+#define PROJECTDOC_OPTIONS 2
 
 _configProxy = new ConfigWidgetProxy( core() );
-_configProxy->createProjectConfigPage( i18n("Bookmarks"), BOOKMARKSETTINGSPAGE );
+_configProxy->createGlobalConfigPage( i18n("My Part"), GLOBALDOC_OPTIONS, info()->icon() );
+_configProxy->createProjectConfigPage( i18n("My Part"), PROJECTDOC_OPTIONS, info()->icon() );
 connect( _configProxy, SIGNAL(insertConfigWidget(const QObject*, QWidget*, unsigned int )), 
-	this, SLOT(insertConfigWidget(const QObject*, QWidget*, unsigned int )) );
+    this, SLOT(insertConfigWidget(const QObject*, QWidget*, unsigned int )) );
 
 ...
 ...
 
-void BookmarksPart::insertConfigWidget( QObject const * dlg, QWidget * page, unsigned int pagenumber )
+void MyPart::insertConfigWidget( QObject const * dlg, QWidget * page, unsigned int pagenumber )
 {
-	if ( pagenumber == BOOKMARKSETTINGSPAGE )
-	{
-		BookmarkSettings * w = new BookmarkSettings( this, page );
-		connect( dlg, SIGNAL(okClicked()), w, SLOT(slotAccept()) );
-	}	
+    if ( pagenumber == PROJECTDOC_OPTIONS ) {
+        MyPartGlobalSettings * w = new MyPartGlobalSettings( this, page );
+        connect( dlg, SIGNAL(okClicked()), w, SLOT(slotAccept()) );
+    } else if ( pagenumber == PROJECTDOC_OPTIONS ) {
+        MyPartProjectSettings * w = new MyPartProjectSettings( this, page );
+        connect( dlg, SIGNAL(okClicked()), w, SLOT(slotAccept()) );
+    }
 }
- 
- </PRE>
- 
- * Note that this replaces the typical KDevPlugin configWidget() and projectConfigWidget() slots.
- */
+@endcode
+
+Note that this replaces the functionality of typical KDevCore::configWidget() and
+KDevCore::projectConfigWidget() slots.
+*/
 class ConfigWidgetProxy : public QObject
 {
 Q_OBJECT
 
 public:
+	/**Constructor.
+	@param core An instance of KDevelop Core.*/
 	ConfigWidgetProxy( KDevCore * core );
 	virtual ~ConfigWidgetProxy();
     
 	/**
-	* Tell the proxy you want a page in the Global Settings. 
-	* @param title The title of the config page, shown in the settings dialog
-	* @param pagenumber A per-proxy unique identifier, used when responding to insertConfigWidget() signal
+	* Tells the proxy you want a page in the Global Settings. 
+	* @param title The title of the config page, shown in the settings dialog.
+	* @param pagenumber A per-proxy unique identifier, used when responding to insertConfigWidget() signal.
+	* @param icon The name of the icon to use.
 	*/
 	void createGlobalConfigPage( QString const & title, unsigned int pagenumber, QString const & icon = "kdevelop" );
 	
 	/**
-	* Tell the proxy you want a page in the Project Settings. 
-	* @param title The title of the config page, shown in the settings dialog
-	* @param pagenumber A per-proxy unique identifier, used when responding to insertConfigWidget() signal
+	* Tells the proxy you want a page in the Project Settings. 
+	* @param title The title of the config page, shown in the settings dialog.
+	* @param pagenumber A per-proxy unique identifier, used when responding to insertConfigWidget() signal.
+	* @param icon The name of the icon to use.
 	*/
 	void createProjectConfigPage( QString const & title, unsigned int pagenumber, QString const & icon = "kdevelop" );
 	
 	/**
-	* Remove a config page from the proxy. Next time the settings dialog opens, this page will not be available.
+	* Removes a config page from the proxy. Next time the settings dialog opens, this page will not be available.
 	* @param pagenumber The identifier set in createGlobalConfigPage() or createProjectConfigPage().
 	*/
 	void removeConfigPage( int pagenumber );
@@ -92,8 +103,8 @@ public:
 signals:
 	/**
 	* The proxy emits this signal to notify the client that a specific config page has been requested.
-	* @param dlg The settings dialog. The client should connect to its okClicked() signal
-	* @param page The setting page. The client should use this as parent to the config widget
+	* @param dlg The settings dialog. The client should connect to its okClicked() signal.
+	* @param page The setting page. The client should use this as parent to the config widget.
 	* @param pagenumber The identifier set in createGlobalConfigPage() or createProjectConfigPage(). Identifies the requested config page.
 	*/
 	void insertConfigWidget( const KDialogBase * dlg, QWidget * page, unsigned int pagenumber );
