@@ -20,17 +20,18 @@
 #include <kdevcore.h>
 #include <kdevapi.h>
 #include <kdevpartcontroller.h>
+#include <kdevplugininfo.h>
 
 #include "astyle_widget.h"
-#include <astyle_adaptor.h>
+#include "astyle_adaptor.h"
 
-static const KAboutData data("kdevastyle", I18N_NOOP("Reformat Source"), "1.0");
+static const KDevPluginInfo data("kdevastyle");
 
 typedef KDevGenericFactory<AStylePart> AStyleFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevastyle, AStyleFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevastyle, AStyleFactory( data ) )
 
 AStylePart::AStylePart(QObject *parent, const char *name, const QStringList &)
-  : KDevSourceFormatter("AStyle", "kdevelop", parent, name ? name : "AStylePart")
+  : KDevSourceFormatter(&data, parent, name ? name : "AStylePart")
 {
   setInstance(AStyleFactory::instance());
 
@@ -105,8 +106,8 @@ void AStylePart::beautifySource()
 
 void AStylePart::configWidget(KDialogBase *dlg)
 {
-	QVBox *vbox = dlg->addVBoxPage(i18n("Source Formatter"), i18n("Source Formatter"), BarIcon( icon(), KIcon::SizeMedium));
-  AStyleWidget *w = new AStyleWidget(vbox, "astyle config widget");
+	QVBox *vbox = dlg->addVBoxPage(i18n("Formatting"), i18n("Formatting"), BarIcon( info()->icon(), KIcon::SizeMedium));
+  AStyleWidget *w = new AStyleWidget(this, vbox, "astyle config widget");
   connect(dlg, SIGNAL(okClicked()), w, SLOT(accept()));
 }
 
@@ -144,20 +145,22 @@ void AStylePart::activePartChanged(KParts::Part *part)
   _action->setEnabled(enabled);
 }
 
-QString AStylePart::formatSource( const QString text )
+QString AStylePart::formatSource( const QString text, AStyleWidget * widget )
 {
-  ASStringIterator is(text);
-  KDevFormatter formatter;
-
-  formatter.init(&is);
-
-  QString output;
-  QTextStream os(&output, IO_WriteOnly);
-
-  while (formatter.hasMoreLines())
-        os << QString::fromUtf8(formatter.nextLine().c_str()) << endl;
-
-  return output;
+	ASStringIterator is(text);
+	KDevFormatter * formatter = ( widget ? new KDevFormatter( widget ) : new KDevFormatter );
+	
+	formatter->init(&is);
+	
+	QString output;
+	QTextStream os(&output, IO_WriteOnly);
+	
+	while ( formatter->hasMoreLines() )
+		os << QString::fromUtf8( formatter->nextLine().c_str() ) << endl;
+		
+	delete formatter;
+	
+	return output;
 }
 
 void AStylePart::cursorPos( KParts::Part *part, uint * line, uint * col )
@@ -182,4 +185,15 @@ void AStylePart::setCursorPos( KParts::Part *part, uint line, uint col )
 	}
 }
 
+QString AStylePart::formatSource( const QString text )
+{
+    return formatSource(text, 0);
+}
+
+QString AStylePart::indentString( ) const
+{
+  KDevFormatter formatter;
+  return formatter.indentString();
+}
+
 #include "astyle_part.moc"
