@@ -24,13 +24,17 @@ class ProjectInfo
 public:
   KURL         m_projectURL;
   QDomDocument m_document;
-  QString      m_projectPlugin, m_language, m_activeLanguage;
-  QStringList  m_ignoreParts, m_loadParts, m_keywords, m_secondaryLanguages;
+  QString      m_profileName;
+  QString      m_projectPlugin, m_language, m_activeLanguage, m_vcsPlugin;
+  QStringList  m_ignoreParts, m_keywords;
 
   QString sessionFile() const;
 };
 
-
+/**
+Project manager.
+Loads and unloads projects.
+*/
 class ProjectManager : public QObject, public KXMLGUIClient
 {
   Q_OBJECT
@@ -67,9 +71,6 @@ private slots:
   void slotLoadProject();
 
   void loadLocalParts();
-
-  void updateActiveLangMenu();
-  void switchLanguage(const QString& lang);
   
 private:
   ProjectManager();
@@ -86,15 +87,21 @@ private:
   bool loadLanguageSupport(const QString& lang);
   void unloadLanguageSupport();
 
+  QString profileByAttributes(const QString &language, const QStringList &keywords);
+  
   ProjectInfo *m_info;
 
   KAction *m_closeProjectAction, *m_projectOptionsAction;
   KRecentFilesAction *m_openRecentProjectAction;
-  KSelectAction *m_activeLanguage;
 
   static ProjectManager *s_instance;
 
   ProjectSession* m_pProjectSession;
+  
+  KDevPlugin *m_vcsPlugin;
+  QString m_vcsName;
+  
+  QString m_oldProfileName;
 };
 
 
